@@ -2,5 +2,5 @@ import sys
 
 from .rrpm import cli
 
-if __name__ == '__main__':
-    sys.exit(cli())
\ No newline at end of file
+if __name__ == "__main__":
+    sys.exit(cli())
